@@ -2,6 +2,7 @@
 """Parser for performing normalization"""
 
 from urduhack.normalization import normalize
+from urduhack.preprocessing import preprocess, normalize_whitespace
 from ..parser import Parser
 
 
@@ -12,5 +13,6 @@ class NormalizeParser(Parser):
         """pass"""
 
     def parse(self, document):
-        """Function to normalize text"""
-        return normalize(document)
+        """Function to normalize|preprocess text"""
+
+        return preprocess(normalize(normalize_whitespace(document)))
