@@ -1,7 +1,7 @@
 # coding: utf8
 """
-Urdu Sentence and Word Tokenization module
-------------------------------------------
+Tokenization
+==============
 
 This module is another crucial part of the Urduhack. This module performs tokenization on sentence. It separates
 different sentence from each other and converts each string into a complete **sentence token**. Note here you must not
@@ -15,6 +15,10 @@ This module provides the following functionality:
 
     - Sentence Tokenization
     - Word Tokenization
+
+The tokenization of Urdu text is necessary to make it useful for the machine
+learning tasks. In the :py:mod:`~urduhack.tokenization` module, we solved the problem related to
+sentence and word tokenization.
 """
 from .tokenizer import sentence_tokenizer, word_tokenizer
 
