@@ -6,6 +6,5 @@ Utils module
 Collection of helper functions.
 """
 from .io import pickle_load, pickle_dump, download_from_url, remove_file
-from .text import load_vocab
 
-__all__ = ["load_vocab", "pickle_load", "pickle_dump", "download_from_url", "remove_file"]
+__all__ = ["pickle_load", "pickle_dump", "download_from_url", "remove_file"]
