@@ -10,7 +10,15 @@ def download():
     """
     _url = MODELS_URL['WORD_TOKENIZER_WEIGHTS']
     file_name = _url.split("/")[-1]
-    download_from_url(file_name=file_name, url=_url, download_dir='models/tokenizer/word/v1')
+    download_from_url(file_name=file_name, url=_url, download_dir='models/tokenizer/word/')
+
+    _url = MODELS_URL["POS_TAGGER_WEIGHTS"]
+    file_name = _url.split("/")[-1]
+    download_from_url(file_name=file_name, url=_url, download_dir='models/tagger/pos/')
+
+    _url = MODELS_URL["NER_WEIGHTS"]
+    file_name = _url.split("/")[-1]
+    download_from_url(file_name=file_name, url=_url, download_dir='models/ner/')
 
     # Sentiment model
     # _url = MODELS_URL['SENTIMENT_V1_WEIGHTS']
